@@ -5,9 +5,9 @@ use warnings;
 
 require 5.010;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
-use Crypt::OpenSSL::X509 1.807;
+use Crypt::OpenSSL::X509;
 
 BOOT_XS: {
     require DynaLoader;
@@ -19,58 +19,6 @@ BOOT_XS: {
       ->( __PACKAGE__, $VERSION );
 }
 
-sub new {
-    if ( scalar(@_) == 2 ) {
-        # Backward compatability Crypt::OpenSSL::Verify
-        # only one parameter is the CAfile name
-        push @_, undef;
-    }
-    my ( $class, %args ) = @_;
-    my $self    = {};
-    my $options = \%args;
-    if ( exists $options->{CAfile} ) {
-        $self = {
-            CAfile         => $options->{CAfile},
-            CApath         => $options->{CApath},
-            noCAfile       => $options->{noCAfile},
-            noStore        => $options->{noStore},
-            trust_expired  => $options->{trust_expired},
-            trust_no_local => $options->{trust_no_local},
-            trust_onelogin => $options->{trust_onelogin},
-            strict_certs   => $options->{strict_certs},
-            STORE          => 0
-        };
-    }
-    else {
-        # Support Crypt::OpenSSL::VerifyX509 calling format
-        if ( keys %args == 1 ) {
-            for ( keys %args ) {
-                my %arg = ( CAfile => $_ );
-                %args = %arg;
-                $self = {
-                    CAfile         => $_,
-                    strict_certs   => 0, # Maintain original functionality
-                    STORE          => 0
-                }
-
-            }
-        }
-    }
-    my $opt = $self;
-    my $store = _new( $class, $opt ) ;
-    if ($store) {
-        $self->{STORE} = $store;
-    }
-    else {
-        $self = 0;
-    }
-    bless $self, $class;
-
-    return $self;
-
-
-}
-
 # Register the sub pcb1
 register_verify_cb( \&verify_callback );
 
@@ -152,7 +100,7 @@ Crypt::OpenSSL::Verify - OpenSSL Verify certificate verification in XS.
 =head1 SYNOPSIS
 
   use Crypt::OpenSSL::Verify;
-  use Crypt::OpenSSL::X509 1.807;
+  use Crypt::OpenSSL::X509;
 
   my $ca = Crypt::OpenSSL::Verify->new(
                 CAfile => 't/cacert.pem',
@@ -264,6 +212,7 @@ Arguements:
 =head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
+Wesley Schwengle <waterkip>
 
 =head1 COPYRIGHT
 
@@ -272,6 +221,7 @@ this distribution, including binary files, unless explicitly noted
 otherwise.
 
 Copyright 2020 Timothy Legge
+Copyright 2020 Wesley Schwengle
 
 Based on the Original Crypt::OpenSSL::VerifyX509 by
 
